from graph import Graph
from bfs import BFS

class WordLadder:
    def __init__(self, filename):
        self.filename = filename
        self.g = self.build_graph()

    def build_graph(self):
        d = {} # { "_ATS": ["CATS", "MATS", ...], ... }
        g = Graph()

        with open(self.filename,'r') as wfile:
            words = wfile.read().split()

        for word in words:
            g.add_vertex(word)
            for i in range(len(word)):
                bucket = word[:i] + '_' + word[i + 1:]
                if bucket in d:
                    d[bucket].append(word)
                else:
                    d[bucket] = [word]

        # łączymy krawędziami słowa w obrębie kubełka
        for bucket in d.keys():
            for word1 in d[bucket]:
                for word2 in d[bucket]:
                    if word1 != word2:
                        g.add_edge(word1, word2)

        return g

    def shortest_path(self, word1, word2):
        bfs = BFS(self.g)
        bfs.bfs(word1)
        return bfs.traverse(word2)


if __name__ == "__main__":
    w_ladder = WordLadder("collins2015.txt")  # slowa.txt dla 4-literowych
    print(w_ladder.shortest_path("MATH", "CATS"))
    print(w_ladder.shortest_path("RIGHT", "WRONG"))
